package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcGzdt;
import org.apache.ibatis.annotations.Param;

/**
 * 工作动态Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcGzdtMapper 
{
    /**
     * 查询工作动态
     * 
     * @param id 工作动态主键
     * @return 工作动态
     */
    public TcGzdt selectTcGzdtById(Long id);

    /**
     * 查询工作动态列表
     * 
     * @param tcGzdt 工作动态
     * @return 工作动态集合
     */
    public List<TcGzdt> selectTcGzdtList(TcGzdt tcGzdt);

    /**
     * 新增工作动态
     * 
     * @param tcGzdt 工作动态
     * @return 结果
     */
    public int insertTcGzdt(TcGzdt tcGzdt);

    /**
     * 修改工作动态
     * 
     * @param tcGzdt 工作动态
     * @return 结果
     */
    public int updateTcGzdt(TcGzdt tcGzdt);

    /**
     * 删除工作动态
     * 
     * @param id 工作动态主键
     * @return 结果
     */
    public int deleteTcGzdtById(Long id);

    /**
     * 批量删除工作动态
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcGzdtByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
