package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcFbqk;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcGzdt;
import com.ruoyi.tcZz.service.ITcGzdtService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 工作动态Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "工作动态")
@RequestMapping("/tcZz/netManage/gzdt")
public class TcGzdtController extends BaseController
{
    @Autowired
    private ITcGzdtService tcGzdtService;

    /**
     * 查询工作动态列表
     */
    @ApiOperation(value = "查询工作动态列表",response = TcGzdt.class)
    @GetMapping("/list")
    public TableDataInfo list(TcGzdt tcGzdt)
    {
        startPage();
        List<TcGzdt> list = tcGzdtService.selectTcGzdtList(tcGzdt);
        return getDataTable(list);
    }

    /**
     * 导出工作动态列表
     */
    @ApiOperation(value = "导出工作动态列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcGzdt tcGzdt)
    {
        List<TcGzdt> list = tcGzdtService.selectTcGzdtList(tcGzdt);
        ExcelUtil<TcGzdt> util = new ExcelUtil<TcGzdt>(TcGzdt.class);
        util.exportExcel(response, list, "工作动态数据");
    }

    /**
     * 获取工作动态详细信息
     */
    @ApiOperation(value = "获取工作动态详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcGzdtService.selectTcGzdtById(id));
    }

    /**
     * 新增工作动态
     */
    @ApiOperation(value = "新增工作动态")
    @PostMapping
    public AjaxResult add(@RequestBody TcGzdt tcGzdt)
    {
        return toAjax(tcGzdtService.insertTcGzdt(tcGzdt));
    }

    /**
     * 修改工作动态
     */
    @ApiOperation(value = "修改工作动态")
    @PutMapping
    public AjaxResult edit(@RequestBody TcGzdt tcGzdt)
    {
        return toAjax(tcGzdtService.updateTcGzdt(tcGzdt));
    }

    /**
     * 删除工作动态
     */
    @ApiOperation(value = "删除工作动态")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcGzdtService.deleteTcGzdtByIds(ids));
    }
    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcGzdt> util = new ExcelUtil<TcGzdt>(TcGzdt.class);
        List<TcGzdt> tcGzdtList = util.importExcel(file.getInputStream());
        tcGzdtService.importUser(tcGzdtList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcGzdtService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcGzdt> util = new ExcelUtil<TcGzdt>(TcGzdt.class);
        util.importTemplateExcel(response, " 工作动态");
    }
}
